@@ -2,12 +2,13 @@ pub use self::{
     arrow::arrow, block_scoped_fn::block_scoped_functions, block_scoping::block_scoping,
     classes::classes, computed_props::computed_properties, destructuring::destructuring,
     duplicate_keys::duplicate_keys, for_of::for_of, function_name::function_name,
-    instanceof::instance_of, new_target::new_target, parameters::parameters,
-    regenerator::regenerator, shorthand_property::shorthand, spread::spread,
-    sticky_regex::sticky_regex, template_literal::template_literal, typeof_symbol::typeof_symbol,
+    instanceof::instance_of, new_target::new_target, object_super::object_super,
+    parameters::parameters, regenerator::regenerator, shorthand_property::shorthand,
+    spread::spread, sticky_regex::sticky_regex, template_literal::template_literal,
+    typeof_symbol::typeof_symbol,
 };
 use serde::Deserialize;
-use swc_common::{chain, comments::Comments, Mark};
+use swc_common::{chain, comments::Comments, pass::Optional, Mark};
 use swc_ecma_visit::Fold;
 
 mod arrow;
@@ -21,6 +22,7 @@ pub mod for_of;
 mod function_name;
 mod instanceof;
 pub mod new_target;
+mod object_super;
 pub mod parameters;
 pub mod regenerator;
 mod shorthand_property;
@@ -50,6 +52,8 @@ where
         new_target(),
         classes(comments),
         spread(c.spread),
+        // https://github.com/Microsoft/TypeScript/issues/5441
+        Optional::new(object_super(), !c.typescript),
         shorthand(),
         function_name(),
         exprs(),
@@ -87,6 +91,9 @@ pub struct Config {
 
     #[serde(default)]
     pub parameters: parameters::Config,
+
+    #[serde(default)]
+    pub typescript: bool,
 }
 
 #[cfg(test)]
